Repository class

NOTE: the content of the class is experimental, clients should not rely on it yet. To get successful verification, the remote repository:

  • must be a valid remote repository with public access,
  • must contain a pubspec.yaml in the location specified by the repository URL,
  • must have the same package name and repository URL in the pubspec.yaml that was used to analyze the package,
  • must have a valid version,
  • must not have a publish_to key.
Available extensions
Annotations
  • @JsonSerializable.new()

Constructors

Repository({required RepositoryProvider? provider, required String host, required String? repository, required String? branch, required String? path})
Repository.fromJson(Map<String, dynamic> json)
factory
Repository.parseUrl(String input)
Parses input and return the parsed Repository if successful, or throws FormatException if it was unable to recognize the pattern.
factory

Properties

branch → String?
The name of the default branch.
final
hashCode → int
The hash code for this object.
no setterinherited
host → String
The host (domain name) of the repository.
final
path → String?
The local path in the repository to the package directory.
final
provider → RepositoryProvider
The type of the software hosting the repository.
final
repository → String?
The relative path to the entry point of the repository.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveUrl(String reference, {String? branch, String? relativeFrom, bool? isEmbeddedObject}) → String

Available on Repository, provided by the RepositoryUrlResolverExt extension

Resolves a reference in relationship with the repository, and returns:
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited
tryResolveUrl(String reference, {String? branch, String? relativeFrom, bool? isEmbeddedObject}) → String?

Available on Repository, provided by the RepositoryUrlResolverExt extension

Resolves a reference in relationship with the repository, and returns:

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

tryParseUrl(String input) → Repository?
Parses input and return the parsed Repository if successful, or returns null if it was unable to recognize the pattern.