pana library
Classes
- AnalysisResult
- NOTE: the content of the class is experimental, clients should not rely on it yet. The normalized and verified references and derived values of the analysis.
- DartSdkInfo
- InspectOptions
- License
- Describes the details of the license detection results. NOTE: the content of the class is experimental, clients should not rely on it yet.
- PackageAnalyzer
- PanaProcessResult
- PanaRuntimeInfo
- PanaTags
- The tags that pana may assign to an analyzed package.
- ProcessedScreenshot
-
A processed screenshot contains paths with processed images as stored using
storeResourceas passed toPackageAnalyzer.inspectPackage. - ProcessOutput
- The output of a process as String or byte stream.
- Pubspec
- Report
- Models the 'new-style' pana report.
- ReportSection
- ReportSectionId
- Repository
- NOTE: the content of the class is experimental, clients should not rely on it yet. To get successful verification, the remote repository:
- SdkConfig
- Configuration class for the SDKs.
- SdkConstraintStatus
- Detailed support coverage for the SDK constraint.
- Summary
- TextOp
- Describes a text operation.
- ToolEnvironment
- UrlChecker
- Checks if an URL is valid and accessible.
- UrlProblem
- UrlProblemCodes
- Possible values for UrlProblem.problem.
- UrlStatus
- The URL's parsed and queried status.
Enums
- ReportStatus
- RepositoryProvider
- The identifier of repository provider, which could influence how relative URLs are resolved.
- RepositoryStatus
- The status of the repository verification.
- TextOpType
- Describes the type of the operation from the view of the original content.
Extensions
Constants
- packageVersion → const String
Functions
-
exampleFileCandidates(
String package) → List< String> - Returns the candidates in priority order to display under the 'Example' tab.
-
runConstrained(
List< String> arguments, {String? workingDirectory, Map<String, String> ? environment, Duration? timeout, int? maxOutputBytes, bool throwOnError = false, FutureOr<bool> retryIf(PanaProcessResult)?, RetryOptions? retryOptions}) → Future<PanaProcessResult> -
Runs the
argumentsas a program|script + its argument list. -
yamlToJson(
String? yamlContent) → Map< String, Object?> ?